@@ -266,9 +266,9 @@ sub run_package {
 	my ($filename, undef, $plugin_hndlr_cr, $plugin_args) = @_;
 								# Second parm (after $filename) _may_ be used to wallop stashes.
 
+	my $has_exit	= 0 ;
 	my $res		= 3 ;
-	my $ts		= localtime(time()) 
-				if DEBUG_LEVEL ;
+	my $ts		= localtime( time() ) if DEBUG_LEVEL ;
      
 	local $SIG{__WARN__}	= \&throw_exception ;
 	my $stdout		= tie (*STDOUT, 'OutputTrap');
@@ -283,9 +283,9 @@ sub run_package {
 	if ($@) {
 								# Error => normal plugin termination (exit) || run time error.
 		$_			= $@ ;
-		/^ExitTrap: (-?\d+)/	? $res = $1 :
+		/^ExitTrap: (-?\d+)/	? do { $has_exit = 1; $res = $1 } :
 								# For normal plugin exit, $@ will  always match /^ExitTrap: (-?\d+)/
-		/^ExitTrap:  /		? $res = 0  :	do {
+		/^ExitTrap:  /		? do { $has_exit = 1; $res = 0 }  : do {
 								# Run time error/abnormal plugin termination.
 	
 								chomp ;
@@ -304,6 +304,8 @@ sub run_package {
 	undef $stdout ;
 	untie *STDOUT;
 
+	$plugin_output = "**ePN $filename: plugin did not call exit()\n".$plugin_output if $has_exit == 0;
+
 	print LH qq($ts run_package: "$filename $plugin_args" returning ($res, "$plugin_output").\n) 
 		if DEBUG_LEVEL & LEAVE_MSG ;
 
